==> apache-drill-1.21.2-src.tar.gz: apache-drill-1.21.2-src/exec/java-exec/src/main/java/org/apache/drill/exec/schema/DiffSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.schema;

import java.util.List;

import org.apache.drill.shaded.guava.com.google.common.collect.Lists;

public class DiffSchema {
    List<Field> addedFields;
    List<Field> removedFields;
    boolean changed = false;

    public DiffSchema() {
        this.addedFields = Lists.newArrayList();
        this.removedFields = Lists.newArrayList();
    }

    public void recordNewField(Field field) {
        addedFields.add(field);
        changed = true;
    }

    public void reset() {
        addedFields.clear();
        removedFields.clear();
        changed = false;
    }

    public void addRemovedField(Field field) {
        removedFields.add(field);
        changed = true;
    }

    public boolean isChanged() {
        return changed;
    }

    @Override
    public String toString() {
        return "DiffSchema{" +
                "addedFields=" + addedFields +
                ", removedFields=" + removedFields +
                '}';
    }
}

==> apache-drill-1.22.0-src.tar.gz: apache-drill-1.22.0-src/exec/java-exec/src/main/java/org/apache/drill/exec/schema/DiffSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.schema;

import java.util.List;

import com.google.common.collect.Lists;

public class DiffSchema {
    List<Field> addedFields;
    List<Field> removedFields;
    boolean changed = false;

    public DiffSchema() {
        this.addedFields = Lists.newArrayList();
        this.removedFields = Lists.newArrayList();
    }

    public void recordNewField(Field field) {
        addedFields.add(field);
        changed = true;
    }

    public void reset() {
        addedFields.clear();
        removedFields.clear();
        changed = false;
    }

    public void addRemovedField(Field field) {
        removedFields.add(field);
        changed = true;
    }

    public boolean isChanged() {
        return changed;
    }

    @Override
    public String toString() {
        return "DiffSchema{" +
                "addedFields=" + addedFields +
                ", removedFields=" + removedFields +
                '}';
    }
}
